From 56b7d78a034187f66e08f3b3e2de55bd878cf9b5 Mon Sep 17 00:00:00 2001 From: Holger Freyther Date: Sat, 18 Nov 2006 16:55:13 +0000 Subject: Micro-Optimisation decreasing initial parsing time by 10% python () {} and python __anonymous () {} are as the same says functions without a name. They get executed when the main bb file is completely parsed. This is used to set information like FILESDIR. This is a python method so it gets evaled which means compiled and executed a lot of times. By moving the code of the anonfunc into a proper method this is only compiled once. The result is is the 10% speed up when parsing. Reindent anonfuncs and new defs without tabs and four spaces --- packages/nis/nis.inc | 6 +++--- 1 file changed, 3 insertions(+), 3 deletions(-) (limited to 'packages/nis') diff --git a/packages/nis/nis.inc b/packages/nis/nis.inc index 479718cf5e..18dd00437a 100644 --- a/packages/nis/nis.inc +++ b/packages/nis/nis.inc @@ -28,7 +28,7 @@ do_install() { # so force the package to be skipped here (this will cause a # 'nothing provides' error) python () { - os = bb.data.getVar("TARGET_OS", d, 1) - if os == "linux-uclibc": - raise bb.parse.SkipPackage("NIS functionality requires rpcsvc/yp.h, uClibC does not provide this") + os = bb.data.getVar("TARGET_OS", d, 1) + if os == "linux-uclibc": + raise bb.parse.SkipPackage("NIS functionality requires rpcsvc/yp.h, uClibC does not provide this") } -- cgit v1.2.3